{% extends 'email/base.html' %} {% import 'email/macro.html' as macro %} {% block body %} В новости {{ newsitem.title }} добавлен новый комментарий:
{% call macro.comment(comment) %} #{{ comment.local_id }} {%- if comment.bl.can_answer_by(parent.author) %} Ответить {%- endif %} {% endcall %}
Он является ответом на ваш комментарий:
{% call macro.comment(parent) %} #{{ parent.local_id }} {% endcall %} {%- endblock %}